#
# spec file for package google-sap-agent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global provider        github
%global provider_tld    com
%global project         GoogleCloudPlatform
%global repo            sapagent
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           google-cloud-sap-agent
Version:        3.2
Release:        150100.3.29.1
Summary:        Google Cloud for SAP
License:        Apache-2.0
Group:          System/Daemons
URL:            https://%{provider_prefix}
Source0:        %{repo}-v%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) = 1.21
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%if 0%{?suse_version} && 0%{?suse_version} == 1220
%define systemd_prefix /lib
%else
%define systemd_prefix /usr/lib
%endif


%{go_nostrip}
%{go_provides}

%description
Google Cloud SAP agent. Agent for GCE instances running SAP workloads.

%prep
%setup -q -n sapagent-v%{version}
%setup -T -D -a 1 -n sapagent-v%{version}

%build
%goprep %{import_path}
pushd cmd/local
go build -mod=vendor -o google_cloud_sap_agent main.go
popd

%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{systemd_prefix}/systemd/system
install -d %{buildroot}%{_datadir}/google-cloud-sap-agent
install -p -m 0755 %{_builddir}/sapagent-v%{version}/cmd/local/google_cloud_sap_agent %{buildroot}%{_bindir}
install -p -m 0622 build/google-cloud-sap-agent.service %{buildroot}%{systemd_prefix}/systemd/system
install -p -Dm 0644 build/configuration.json %{buildroot}%{_sysconfdir}/%{name}/configuration.json

%pre
%service_add_pre google-cloud-sap-agent.service

%preun
%service_del_preun google-cloud-sap-agent.service

%post
%service_add_post google-cloud-sap-agent.service

%postun
%service_del_postun google-cloud-sap-agent.service


%files
%defattr(0644,root,root,0755)
%dir %{_sysconfdir}/%{name}
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/%{name}/configuration.json
%license LICENSE
%{_datadir}/google-cloud-sap-agent
%attr(0755,root,root) %{_bindir}/*
%{systemd_prefix}/systemd/system/google-cloud-sap-agent.service

%changelog
* Wed Apr  3 2024 adrian.glaubitz@suse.com
- Update to version 3.2 (bsc#1222215, bsc#1222216)
  * Remove internal gensupport package.
  * Restore additional error handling and response checking to internal data warehouse client.
  * Updating the aggregate function in HANA insight rules
  * Remove a leftover debug log
  * Allow multipart uploads for PIPE file types.
  * Update go-hdb version to v1.8.0
  * Perform log restores in serial rather than parallel.
  * Add sample usage examples to commandlineexecutor
  * Small update to configureinstance OTE
  * Add nil check in backup and restore flows to protect against panics.
  * Close http response body in WriteInsight() and soap.go
  * Record topology type.
  * Initialize usagemetrics for OTEs
  * Add Instance Number to SAP System instance properties
  * Set `min_version` for WLM `os_settings` system metric.
  * Increase timeout for saptune re-apply commands.
  * Adding handling for encrypted snapshots in backup and restore
  * Change the version check comparisons to account for versions
    older than those listed in SAP Note.
  * Skip the Netweaver metrics that need dpmon on NW kernels
    affected by SAP Note: 3366597
  * Fix imports
  * No public description
  * Use internal data warehouse client.
  * Fix disp+work command invocation for Netweaver Kernel version discovery.
  * Add note about default parameter values to installbackint.
  * Add mutex in multipart writer for potential data races.
  * Update go.mod and go.sum
  * Skip XFS freeze by default unless user passes a parameter to do it explicitly
  * configureinstance minor updates.
  * Add safety check for usage metrics on BMS
  * Storage Class parameter added to Backint.
  * Update configureinstance's X4 saptune conf.
  * XML Multipart Write() and Close() methods completed.
  * Fixes the vmmanager policies for sles12 and sles15 used in the cloud console removes
    the individual cloud console policies and consolidates them into one Adds a general
    gcloud command line policy
  * Standardize logging for workloadmanager package.
  * Multipart XML API Uploads for Backint.
  * Add database system SID to database properties.
  * Fix NW HA node identification for RedHat deployments.
  * Add workload properties to discovery object returned by discoverSAPSystems
  * Add ASCS instance number to application data
  * Add Workload Manager validation rule for checking OS settings.
  * Enable WLM metric collection by default, disable submission of data to Cloud Monitoring.
  * Decoupling primary executable command and providing an alternative to lsof
  * Added HANA version in support bundle collection
  * Add WorkloadProperties to merged system details and to WLM Insights
  * Replace the link placeholder with the actual link
  * Add instance number to SAP discovery data
  * Tranche 12: HRE Rules
  * Minor typo fix in workloadmanager's hana metrics module
  * Add pacemaker metrics with SID labels to process metrics
  * updating the regex for backup and backint files to take care of log rotation in support bundle
  * Add support for disk snapshot labels for easy lifecycle management of snapshots
  * Added new OTE for changedisktype workflow
  * Add WorkloadProperties to SapSystemDetails for apps_discovery
  * Testing the timeseries in unit tests instead of just checking the count
  * Record Netweaver kernel version.
  * Tranche 12: HRE Rules
  * Testing the timeseries in unit tests instead of just checking the count
  * Testing the timeseries in unit tests instead of just checking the count
  * Relocating pacemaker collection related packages to internal/pacemaker
    for common use between process metrics and WLM
  * Use results from latest round of discovery for the collection of process metrics.
  * Handling zero rows returned case better in HANA insights
  * Adding docstrings to workloadmanager package
  * Adding docstring to configure OTE
  * adding docstrings to methods in support bundle
  * Add X4 specific configurations to configureinstance OTE.
  * Add helper functions to configureinstance OTE.
  * Display updates for HANA Insights WLM rules rollout.
  * configureinstance OTE
  * We expect the command to return a non-zero exit code and we should not be
    returning an error. Execute treats non-zero exit code as error.
  * Removing the sap control process command line params
  * Revert "Fixing system replication status code being returned"
  * configureinstance OTE
  * We expect the command to return a non-zero exit code and we should not be
    returning an error. Execute treats non-zero exit code as error.
  * Removing the sap control process command line params
  * Fixing system replication status code being returned
  * Wait for hdbindex server to stop after HANA is stopped
  * Log error to console in cases where LVM is not being used
  * Adding JournalCTL logs to support bunddle
  * hanadiskbckup - Add missing params to the Usage string
  * Move usagemetrics package into shared folder
  * Fixed data race error in TestCollectAndSendSlowMovingMetrics()
  * Disk backup/restore - Enable send-metrics-to-monitoring by default
* Tue Feb 20 2024 adrian.glaubitz@suse.com
- Update to version 3.1 (bsc#1220010, bsc#1220111)
  * Fixing system replication status code being returned
  * Reduce disk snapshot wait durations
  * Fix test flakes in workloadcollector test.
  * adding metrics for db freeze time and total workflow time
  * Fix for SAP System discovery adding the current host to all components.
  * Restore default WLM metric collection settings.
  * change description of validate OTE
  * fix a typo in the command name and add a delay before we try the unmount
  * Use underscore as separator for flags in place of hyphens
  * Enable host_metrics and disable reliability_metrics by default in configure OTE
  * Collect reliability metrics in the free namespace
  * Remove user from cmd params for HANA Replication
  * Enable workload manager metric collection by default.
  * Add support configuration flag to enable legacy WLM metric data submission workflow.
  * Lowers the log level of discovery to info
  * Fix for HANA Replication Config
  * Add additional instance-id parameter for users who do not want to provide port number
  * Use _ instead of - for parameters in configurebackint
  * Implementing panic recovery to HANA Monitoring: CreateWorkerPool
  * Fix issue with process metrics subroutine starting.
  * Add a flag to enable or disable workload discovery.
  * Reduce logs in sapdiscovery to debug, these are now run a
    lot more frequently and are flooding the logs
  * Use bucket `cloudsapdeploystaging` for staging environment.
  * Updates default value handling for system discovery flag.
  * Added default values to some frequency flags in configure OTE
  * force a sync before unmounting to clear out stale file handles
  * Retain recoverable routine in process metrics.
  * Ensures slow metrics workers stop on context cancellation.
  * Log lsof output if unmount fails during restore
  * SAP Discovery - Discover R3trans data
  * Add panic recovery to collectiondefinition update routine
  * configurebackint OTE.
  * Adding panic recovery to remote.go
  * Prevent host metrics from restarting the daily metrics report if it has already been started.
  * Add panic recovery to agent metrics
  * Implementing panic recovery for hana monitoring: logging action daily
  * Routines now use their own context and cancel in the event of a panic recovery.
  * Add panic recovery to host metrics routines
  * Removed -path flag and fixed usage string
  * Add workload properties to the SAP System definition.
  * Add panic recovery to collectMetricsFromConfig routines.
  * Add panic recovery to fast metric collection routine.
  * Reduces the log severity to debug for the exponential backoff policy
  * Add panic recovery to heartbeat routine.
  * Updating configuration.json file to remove deprecated sap_discovery field
  * Use protojson instead of custom function for snake_case marshaling
  * Add panic recovery to WLM metrics collection
  * HANA Insights rules tranche 11: Create unit tests and add to auto push
  * Add panic recovery to workload collector daily usage metrics.
  * Processmetrics - suppress Error and Warn logs that really need to be debug
  * Formatting the output of messages printed by configure OTE
  * Changing flag names of configure OTE to align better with configuration.json fields
  * Add automatic panic recovery to slow metrics collection
  * Add panic recovery to goroutine collectAndSend
  * Add panic recovery to goroutine
  * Retain recoverable routines beyond function scope.
  * Implement recovery handler for SAP System discovery package
  * Tranche 11: HRE Rules
  * Update github build
  * Adds generic panic recovery to SAP System discovery package
  * Initialize the sidadm env to ensure restore can be run as root user
  * not pacaking gcbdr scripts till launch of the feature
  * Change datatype of frequency flags from string to int
  * Breaking down --frequency flag into separate flags for different features for better isolation
  * Fix configuration.json file from being written in camelCase to snake_case
  * Tranche 6,7,8,9,10: HRE Rules
  * Suppress pacemaker related log from Error to Debug
  * creating the OTE for GCBDR discovery
  * Update HA node identification
  * Tranche 10: HRE Rules
  * Update file permissions and ownership for installbackint when running as root.
  * Adding newline after version print.
  * Exposing HANA Logical volumes availability metrics
  * Make workloadmanager parameters test more robust.
  * Fix panic in cloud discovery
  * Tranche 10: HRE Rules
  * Add recovery_folder_prefix parameter to Backint.
  * Mark process_metrics_send_frequency as deprecated
  * Add snapshot-type param to hanadiskbackup with default as STANDARD
    type. Users can override to ARCHIVE type if needed.
  * Add new folder_prefix parameter to Backint.
  * Add HANA new HANA insight rules to BUILD file and embed sources
  * Tranche 10a: HRE Rules
  * Tranche 6b: HRE Rules
  * Tranche 8b: HRE Rules
  * Fix for sending isABAP value
  * Updating logusage command line flags
* Thu Jan 25 2024 adrian.glaubitz@suse.com
- Update to version 3.0 (bsc#1218736, bsc#1218737)
  * Suppress packemaker command error to debug to avoid log flooding
  * Expand load balancing cluster discovery.
  * Log success messages in OTEs to STDOUT instead of STDERR used by log.Print
  * Use bash always to avoid variation of behavior across OS/Shell types
  * Minor updates to installbackint.
  * Backint compose step properly saves metadata.
  * Fix issue with discovery on ASCS instances.
  * hanadiskrestore - fix the format of disktype string for disk create API
  * Fix issue with PCS cluster address discovery.
  * Update transform to insight
  * Rename HANA backup/restore OTEs to reflect they are supported
    for all disks and not just persistent disk
  * Increase the timeout for HDB stop to account for busy DBs
  * Adding project sap-ecs-testing to the list.
  * PD Restore - Support provisioned-iops and provisioned-throughput
  * Integration test for configure OTE
  * Added precondition in hana pd backup for stripped LVM
  * Add a precondition check to verify user has passed a valid
    snapshot name that is present in the current project
  * Update the usage to reflect additional required param
  * Minor path update for supportbundle OTE.
  * Fixing bug in slow moving metrics partial collection scenarios
  * Adding check for agent status after restart.
  * Ensure Backint ComposeChunks has a valid bucket handle
  * Discover whether a Netweaver instance is ABAP or Java
  * Replace standard slices package with third party version
  * WLM HANA metric `ha_in_same_zone` now reports instance
    names for HA nodes in the same zone
  * Fix data race condition for Backint Backup with new client connections
  * Make -new-disk-name a required parameter to avoid the 63 char
    limit in the name length due to auto-generated names
  * Fix command for collecting Corosync metric `two_node_runtime`
  * Make snapshot name similar to disk name
  * Bump golang.org/x/crypto from 0.15.0 to 0.17.0
  * Enable Discovery config flag controls submission
    to Data Warehouse and Cloud Logging
  * Create new clients for each operation in Backint
  * Add `client_endpoint` to Backint proto.
  * Getting the build number into the version for display
  * Backint config name change: service_account to service_account_key
  * Add HANA HA metrics to collection definition.
  * Fix sorting bug in a diff in apps_discovery_test.go
  * Add discoverHANATenantDBs to main code path
  * Change PIPE filemode to WRONLY to allow us to detect broken pipes
  * Deprecate `sap_system_discovery` config field in favor of `enable_discovery`
  * Move the validation of whether user passed correct PD, before stopping HANA
  * Add a placeholder for public doc link with next steps
    after hanapdrestore workflow has completed
  * Fix executable path for HDB version command
  * Add optional param `new-disk-name` to hanapdrestore
    for users that wish to override the default
  * Sort the skipmetrics in unit test to avoid order related flakes
  * Generalizing configure OTE
  * Discover Netweaver kernel version
  * Fix Sprintf call
  * Use SAP System data to determine if HANA HA nodes share the same zone.
  * hanapdrestore - do not delete PDs in case of failures
  * Create discoverHANATenantDBs method to support multiple SIDs for HANA tenant DBs
  * Send additional fields in Data Warehouse WriteInsightRequest
  * Updating the username parameters for hana pd backup and restore
  * Retrieve Reliability data every 2 hours instead of 24
  * Discover HANA version
  * Fix import for GitHub build
  * Add instance properties, and topology information to system data
  * Keep the device nam and disk name same after restore
  * Move sapdiscovery package into system package
  * Changer the default name of the disk created by restore workflow
  * Updates the generated protobuf go for system.proto
  * Update generated system proto
  * Update go.yml
  * Add topology and instance properties info to SAP System data
  * Add a check to verify the disk is attached to instance, fail if disk is not attached
  * Add application and database software properties to system representation
  * Fix race condition in heartbeat test case
  * Add error handling to restore workflow to try and keep
    the HANA system in a clean state on failures
  * Enable LogToCloud by default for both OTE and Daemon modes
  * Bump Agent version to 3.0
  * Reliability OTE added to SAP Agent
  * Declare public Get interface for SAP System discovery data
  * Integration testing for Networkstats Package
  * Adding project sap-ecs-testing to the list
  * Adding one time execution for enabling/disabling of features
  * Change to using custom retries for initial bucket connection
  * Default collection definition to be fetched from GCS
  * Add a 2 minute context timeout for initial bucket connection
  * Add `collection_config_version` as a WLM system metric
  * Make project, host param optional for hanapdbackup,
    in addition make user param optional for hanapdrestore
  * Fix potential nil dereference WLM metrics collection
  * Add force-stop-hana to restore workflow to forcefully stop
    HANA when the param is passed
  * Rename the HANA PD snapshot and restore workflows
  * Add unit tests for GetProvisionIOps and GetProvisionedThoughput
  * Remove the TestCollect unit test which relies on nc
    command which can be flaky in unit tests
  * Increase Backint timeout for PIPE files to 3 minutes
  * Add XFS freeze and unfreeze to PD based snapshot
* Tue Nov 28 2023 adrian.glaubitz@suse.com
- Update to version 2.8 (bsc#1217373, bsc#1217374)
  * Bump agent version to 2.8 to support C3/M3 certification
  * Update go.yml to use go 1.21
  * Switch from "slices" to "go_exp.../slices" for go version dependency
  * Use newly refactored discovery packages.
  * Fixes issue with diskname from source or device name
  * Adds extreme disk type IOps and Throughput for host metrics
  * Add `INTEGRATION` target config environment for collection definition testing
  * Add project number to SAP System proto
  * Add a cache to discovered resources. This reduces the number of API
    calls needed to perform System Discovery
  * Replace windows wmic hardware queries with PowerShell wmi queries
  * Fix test flakiness
  * Improve development process for collection definition configuration
  * HANA PD based snapshot and restore - changes to add wait for uploading
  * Fix for kokoro build issue in processmetrics/networkstats
  * GCBDR SAPCoreAPP Package in Agent for SAP
  * Add version tracking for WLM validation config
  * Send workload validation config to remote instances for use during remote collection
  * Add flag for passing in workload validation config into remote collection OTE
  * Bump google.golang.org/grpc from 1.58.2 to 1.58.3
- from version 2.7
  * Added ote for hma dashboards migration
  * Increase Max backoff in storage package to 300 seconds
  * Added subpaths for collection of required TCP metrics
  * Add more debug logs and increase the wait-time for PD operations in restore
  * No public description
  * Add 30 second timeout to read/write from the local file system for Backint
  * No public description
  * Adds RHEL 9 VM Manager policy
  * Extract cloud-related discovery functions into separate file
  * Adding timeout to systemReplication.py command execution
  * Allow download attempts without verifying connection to bucket
  * Invoke `collectiondefinition.Start` when starting the agent in daemon mode
  * SAP Agent CLI - usability improvements for flags and help menu
  * Add host project information to HANA DB component discovery data.
  * Use proto names for default configuration during Backint installation
  * Extending logging capabilities to all packages of the agent
  * Added a feature for exposing TCP connection metrics
  * Migrating context logging logic to all packages of SAP Agent
  * Add an ifthisthenthatlint to ensure new script is kept in sync with rule proto
  * (collectiondefition) - Discard unknown fields and remove breaking metrics
  * Moving commandlineexecutor from internal to shared for sqlserveragent
  * Define startup function for collectiondefinition package
  * Check error on close of destFile in backint restore
  * Allow trailing zeros for millisecond timestamps in Backint
  * Add pid to all agent logs
  * Bump SAP Agent version to 2.7 (placeholder release version)
  * Separate collection definition validation functionality into a separate file
  * Add datetime to migration folder for Backint installation
  * Add symlink for Backint log file to install directory
  * Set a deadline for the final flush to cloud logging
  * Increase chunk retry deadline in storage package
  * Fix order dependent tests in sapagent/internal/storage
  * Change support bundle feature to collect the OTE logs from new path
  * Usage logging for remote WLM validation metrics collection from the collector instance
  * Extract discovery functions performed on the host to a separate file
  * Improve agent shutdown experience in daemon mode
  * Fix Backint restoring incorrect file
  * Google Events - rule proto initial submission
  * Move gce package to shared folder for use by SQL Server agent
  * Add GCS integration into collectiondefinition package
  * Standardize import aliases
  * go mod updates
  * Fixing go/gotsan data race error in processmetrics_test
  * Add Backint support for Inquire line: `#EBID <external_backup_id>`
  * Chown Backint install directories to user/group of the opt/ folder
  * Create OTE logs under a subdir under /var/log as /var/log is only writable by root
  * Will not create an empty log file for logusage logs and one
    time execution logs will have 0666 file mode
  * Setting the log file created to world read+write permission
  * Bump golang.org/x/net from 0.15.0 to 0.17.0
  * Add recovery_bucket parameter to Backint
  * Extract SAP related discovery functions to a separate file
  * Fix Backint install directory
  * Fix Backint parallel uploads
  * Move maintenance collector to beta API
  * Pruning batches to prevent time series duplication
  * Added a logger for incorporating service context keys in logs
  * Encode the DB password string to handle passwords with special characters
  * Handling non error scenarios better in netweaver.go
  * Internal change
  * fixes typo on backint install
  * Allow all users to execute google_cloud_sap_agent
  * Fix hdbbackint script.
  * Subdirs for Backint DIAGNOSE temporary files
  * Report zero-value metrics for upcoming maintenance
  * Clean up gcealpha functionality
  * Fix default configuration values in daemon and backint
  * Update the comment in proto to reflect that the metric
    path in skip list should start with /sap
  * Implemented separation of context of different services
* Fri Oct 20 2023 adrian.glaubitz@suse.com
- Update to version 2.6 (bsc#1215672, bsc#1215673)
  * Rolling back previous change for storing Project Number,
    Project ID is sufficient, no need to add complexity
  * Determine location of HANA global.ini using SAP system discovery logic
  * Add numeric project ID prefix to object name for ReadMetrics
  * Discovery now looks up and stores project number with discovery data
  * ReadMetrics updates for IAM permissions and bucket object names
  * fixing the bug in backoff logic, using separate policies
    for each collector and adding some logs
  * Backint migration from the old agent and supporting legacy parameters
  * adding new backoff policies for process metrics and fixing the
    bug in process metrics sapservice collector
  * Bump SAP Agent version to 2.6
  * Fix an issue where HANA hosts may not be discovered
    properly if hostname differs from instance name
  * Use Go 1.20 friendly sorting solution
  * adding retries in process metrics logic with backoffs
  * Fix parsing of instance (host/VM) name in Pacemaker pcmk_delay_max metric
  * Add the collection definition changes for the SAP HANA Topology metrics
  * Template for Cloud Monitoring Alerts for Backint errors
  * adding backoff to InstanceProperties to each collector
  * Reduced the number of parameters of startXX functions
    by consolidating them into respective structs
  * completing TODO (b/298315981): Create a map from skipped
    list metrics and pass it to collectors.
  * Proto package name changes to reflect the current path
  * Use instance_name instead of instance_id for baremetal systems
  * Decode encryption keys for Backint.
  * Moving hareplication metric to fast moving metrics
  * Added backoffs package in process metrics to keep the backoff policies
    and retry policies separately and make it reusable acrosss process metrics
  * Install Backint OTE
  * Adding skip list logic to process metrics
  * Separating fastmoving metrics into a separate file from other process metrics
  * Update remote collection to use collected instance's Cloud Properties
  * ReadMetrics upload to bucket and send status to monitoring
  * Remove local implementation of DW API in favor of using generated third_party version
  * ReadMetrics read input file and write results to local filesystem
  * Clean up command line executions to collect SAP Control metrics
  * Adding new OTE structure for ReadMetrics
  * Add the SUSE specific spec file to keep upstream changes and SUSE packaging in sync
  * Collect and report upcoming maintenance
  * Add basepath override and gcealpha functionality
  * Making proto changes for process metrics re-arch
  * Changes for generating HANA Insights locally into a markdown file
  * Delay feature specific daily action logs by 24 hours
    to avoid noise created by startup failures
  * Update to the rule "maximum_invalid_connect_attempts"
  * Add some missing related resources
  * Fix rate limiting for compression enabled uploads/downloads
  * Optional User-Agent parameter added to storage package client connection
  * Relocate gcealpha to /internal
  * Fix parse_test error
  * Retries added for opening files in Backint
  * Make processmetrics unit tests hermetic
  * Remove if-this-then-that requirement from WLM validation rule
  * Fix WriteInsight JSON encoding, and add missing elements
  * Add configuration value to change API endpoint for Data Warehouse calls
  * Storage package progress messages based off of read/writes directly to the bucket
  * Make Collect DB Metrics as NO-OP when metrics are being read from override file
  * Remove unused field from backint proto
  * Custom retries for the storage package with exponential backoff and MaxRetries setting
* Thu Aug 31 2023 adrian.glaubitz@suse.com
- Update to version 2.5
  + No upstream changelog provided
* Thu Aug 17 2023 adrian.glaubitz@suse.com
- Install missing default configuration file (bsc#1214293)
* Wed Jul 19 2023 adrian.glaubitz@suse.com
- Update to version 2.1 (bsc#1213397)
  + No upstream changelog provided
* Wed Jul 12 2023 adrian.glaubitz@suse.com
- Update to version 2.0 (bsc#1211516, bsc#1211517)
  + No upstream changelog provided
* Mon May  8 2023 adrian.glaubitz@suse.com
- Update to version 1.5.1 (bsc#1210464, bsc#1210465)
  + No upstream changelog provided
- Raise golang API version to 1.20
* Thu Feb 16 2023 rjschwei@suse.com
- Initial build (#jsc-PED-2879)
  + Version 1.0
